@@ -965,11 +965,11 @@ nautilus_burn_iso_run_process (NautilusBurnIso            *iso,
 gboolean
 nautilus_burn_iso_graft_get_info (NautilusBurnIsoGraft *graft,
 				  guint64              *size,
-				  gboolean             *use_joliet,
+				  gboolean             *use_joliet_out,
 				  GError              **error)
 {
 	GPtrArray            *argv;
-	gboolean              _use_joliet;
+	gboolean              use_joliet;
 	char                 *stdout_data;
 	char                 *stderr_data;
 	int                   exit_status;
@@ -978,7 +978,7 @@ nautilus_burn_iso_graft_get_info (NautilusBurnIsoGraft *graft,
 	char                 *filelist;
 	gboolean              result;
 
-	_use_joliet = TRUE;
+	use_joliet = TRUE;
 	argv = NULL;
 	filelist = create_temp_graft_file (graft);
 	iso_size = 0;
@@ -991,7 +991,7 @@ nautilus_burn_iso_graft_get_info (NautilusBurnIsoGraft *graft,
 
 	g_ptr_array_add (argv, "mkisofs");
 	g_ptr_array_add (argv, "-r");
-	if (_use_joliet) {
+	if (use_joliet) {
 		g_ptr_array_add (argv, "-J");
 	}
 	if (ncb_mkisofs_supports_utf8 ()) {
@@ -1008,6 +1008,9 @@ nautilus_burn_iso_graft_get_info (NautilusBurnIsoGraft *graft,
 	g_ptr_array_add (argv, NULL);
 
 	sub_error = NULL;
+	stdout_data = NULL;
+	stderr_data = NULL;
+	exit_status = 0;
 
 	if (! g_spawn_sync (NULL,
 			   (char **)argv->pdata,
@@ -1025,17 +1028,21 @@ nautilus_burn_iso_graft_get_info (NautilusBurnIsoGraft *graft,
 		g_error_free (sub_error);
 
 		g_ptr_array_free (argv, TRUE);
+		argv = NULL;
 
 		result = FALSE;
 		goto done;
 	}
 
 	g_ptr_array_free (argv, TRUE);
+	argv = NULL;
 
 	if (exit_status != 0 && use_joliet) {
 		if (strstr (stderr_data, "Joliet tree sort failed.") != NULL) {
 			g_free (stdout_data);
 			g_free (stderr_data);
+			stdout_data = NULL;
+			stderr_data = NULL;
 			if (ask_disable_joliet (NULL)) {
 				use_joliet = FALSE;
 				goto retry;
@@ -1062,6 +1069,9 @@ nautilus_burn_iso_graft_get_info (NautilusBurnIsoGraft *graft,
 	if (size != NULL) {
 		*size = iso_size;
 	}
+	if (use_joliet_out != NULL) {
+		*use_joliet_out = use_joliet;
+	}
 
 	return result;
 }
